import urllib2
import EXIF

# Create your views here.
from django.core.urlresolvers import reverse, reverse_lazy
from django.utils.translation import ugettext as _
from django.conf import settings
from django.shortcuts import get_object_or_404, render_to_response
from django.http import HttpResponse, HttpResponseRedirect, Http404
from django.template import RequestContext
from django.contrib.auth.decorators import login_required
from django.contrib import messages
from django.views.generic import DetailView, CreateView, TemplateView

from photos.forms import PhotoForm
from photos.models import Brand, GadgetModel, Photo, PhotoSpec
import EXIF # from root project


class PhotosView(TemplateView):
    """
    List the photos
    """
    template_name = "photos/photos_ajax.html"
    photos = Photo.objects.all()
    q = ''

    def get(self, request, **kwargs):
        q = request.GET.get('q')
        if 'myphoto' in request.GET:
            self.photos = self.photos.filter(user=request.user)
        if 'q' in request.GET:
            self.photos = self.photos.filter(gadget_model__pk=request.GET['q'])
        self.q = q
        context = self.get_context_data(**kwargs)
        return self.render_to_response(context)

    def get_context_data(self, **kwargs):
        context = super(PhotosView, self).get_context_data(**kwargs)
        context['user_photos'] = self.photos
        context['q'] = self.q
        return context


class PhotoDetailView(DetailView):
    """
    Show photo templates
    """
    template_name = "photos/photo_details.html"

    def get_object(self):
        """
        Get the object photo
        """
        return get_object_or_404(Photo, pk=self.kwargs['photo_id'])

    def get_context_data(self, **kwargs):
        context = super(PhotoDetailView, self).get_context_data(**kwargs)
        context['photo'] = self.get_object()
        return context


class PhotoDeleteView(PhotoDetailView):
    """
    Delete a photo
    """
    def get(self, request, **kwargs):
        photo = self.get_object()
        if photo.user == request.user:
            photo.delete()
            messages.add_message(request, messages.SUCCESS, _("You deleted the photo."))
            return HttpResponseRedirect(reverse('home'))
        else:
            raise Http404


class PhotoUploadView(CreateView):
    template_name = None
    form_class = PhotoForm
    success_url = reverse_lazy('home')

    def form_valid(self, form):
        photo_form = form.save(commit=False)
        photo_form.user = self.request.user
        photo_form.save()
        photo = settings.VAR_ROOT + str(photo_form.photo.url).replace('%s', ' ')
        f = open(photo, 'rb')
        # start parsing the photo meta data.
        data = EXIF.process_file(f)
        if 'Image Make' in data:
            # Get the brand and gadget model
            brand, create = Brand.objects.get_or_create(name=data['Image Make'])
            gadget, create = GadgetModel.objects.get_or_create(name=data['Image Model'], brand=brand)
            photo_form.brand = brand
            photo_form.gadget_model = gadget
            photo_form.save()
            try:
                del data['JPEGThumbnail']
            except Exception:
                pass
            # save the parse meta data from a photo
            for key, value in data.items():
                try:
                    PhotoSpec.objects.get_or_create(name=key,
                                                value=value,
                                                photo=photo_form)
                except Exception:
                    pass
        else:
            photo_form.delete()
        return HttpResponse('success')